// Copyright 2019-2021 Varjo Technologies Oy. All rights reserved.

#ifndef VARJO_PLUGIN_H
#define VARJO_PLUGIN_H

#include "Varjo_export.h"
#include "Varjo_types.h"
#include "Varjo_plugin_common.h"

#if defined __cplusplus
extern "C" {
#endif  // __cplusplus

/**
 * Starts the tracker processing
 * @param context - plugin session context acquired from @ref varjo_PluginInit
 * @return @ref varjo_PluginStatus_OK if tracker started successfully, other value of
 *         type @ref varjo_PluginStatus otherwise
 */
VARJO_API varjo_PluginStatus varjo_TrackerStart(varjo_PluginContext context);

/**
 * Stops the tracker processing
 * @param context - plugin session context acquired from @ref varjo_PluginInit
 * @return @ref varjo_PluginStatus_OK if tracker stopped successfully, other value of
 *         type @ref varjo_PluginStatus otherwise
 */
VARJO_API varjo_PluginStatus varjo_TrackerStop(varjo_PluginContext context);

/**
 * @brief Queries tracker for the HMD pose
 *
 * <em>
 * HMD's tracking point is defined to be in the middle - between the centers of eye-piece
 * lenses, and the on plane of the lens surface closest to the user eyes.
 * </em>
 *
 * @image html HMD_Angled.png width=30%
 * @image html HMD_Side.png width=30%
 * @image html HMD_Top.png width=30%
 *
 * <em>
 * An important consideration for tracking systems requiring marker objects to be placed on the HMD
 * is to minimize interference with critical HMD components (cameras, sensors, ventilation, etc.)
 * shown in following images:
 * </em>
 *
 * @image html HMD_sensors_front.png width=30%
 * @image html HMD_sensors_side.png width=30%
 * @image html HMD_sensors_top.png width=30%
 *
 * @param context - plugin session context acquired from @ref varjo_PluginInit
 * @param timeStamp - timestamp in nanoseconds for which tracking prediction is requested
 * @param pose - Pointer to a structure receiving tracking pose
 * @return @ref varjo_PluginStatus_OK if HMD pose was queried successfully, other value of
 *         type @ref varjo_PluginStatus otherwise
 */
VARJO_API varjo_PluginStatus varjo_GetHMDPose(  //
    varjo_PluginContext context,                //
    varjo_Nanoseconds timeStamp,                //
    varjo_DevicePose* pose);

#if defined __cplusplus
}  // extern "C"
#endif  // __cplusplus

#endif  // VARJO_PLUGIN_H
